@@ -9,7 +9,7 @@ class SettingsDialog(QDialog):
         super().__init__(parent)
         self.settings = parent.settings
         self.parent = parent
-        self.setWindowTitle("Configure ssmtool")
+        self.setWindowTitle("Configure SSM")
         self.initWidgets()
         self.initTabs()
         self.setupWidgets()
@@ -17,10 +17,11 @@ class SettingsDialog(QDialog):
         self.setupAutosave()
 
     def initWidgets(self):
-        self.allow_editing = QCheckBox("Allow directly editing of text fields (Requires restart to take effect)")
+        self.allow_editing = QCheckBox("Allow directly editing of text fields")
         self.lemmatization = QCheckBox("Use lemmatization (Requires restart to take effect)")
         self.lemmatization.setToolTip("Lemmatization means to get the original form of words."
             + "\nFor example, 'books' will be converted to 'book' during lookup if this option is set.")
+        self.remove_spaces = QCheckBox("Remove generated spaces when exporting to Anki (Japanese, Chinese)")
         self.target_language = QComboBox()
         self.deck_name = QComboBox()
         self.tags = QLineEdit()
@@ -32,6 +33,30 @@ class SettingsDialog(QDialog):
         self.word_field = QComboBox()
         self.definition_field = QComboBox()
         self.definition2_field = QComboBox()
+        self.pronunciation_field = QComboBox()
+        self.forvo = QCheckBox("Play Forvo pronunciation upon word selection")
+
+        self.orientation = QComboBox()
+        self.text_scale = QSlider(Qt.Horizontal)
+
+        self.text_scale.setTickPosition(QSlider.TicksBelow)
+        self.text_scale.setTickInterval(10)
+        self.text_scale.setSingleStep(5)
+        self.text_scale.setValue(100)
+        self.text_scale.setMinimum(50)
+        self.text_scale.setMaximum(250)
+        self.text_scale_label = QLabel("1.00x")        
+        self.text_scale_box = QWidget()
+        self.text_scale_box_layout = QHBoxLayout()
+        self.text_scale_box.setLayout(self.text_scale_box_layout)
+        self.text_scale_box_layout.addWidget(self.text_scale)
+        self.text_scale_box_layout.addWidget(self.text_scale_label)
+
+        self.orientation.addItems([
+            "Vertical", 
+            "Horizontal", 
+            ])
+
         self.anki_api = QLineEdit()
         self.about_sa = QScrollArea()
         self.host = QLineEdit()
@@ -43,19 +68,23 @@ class SettingsDialog(QDialog):
         self.about = QLabel(
             '''
 © 2021 FreeLanguageTools<br><br>
-Simple Sentence Mining (ssmtool) is free software available under the terms of \
+Visit <a href="https://freelanguagetools.org">FreeLanguageTools.org</a> for more info on how to use this tool.<br>
+You can also talk to us on <a href="https://webchat.kde.org/#/room/#flt:midov.pl">Matrix</a>
+or <a href="https://t.me/fltchat">Telegram</a> for support.<br><br>
+
+Simple Sentence Mining (SSM, ssmtool) is free software available under the terms of
 <a href="https://www.gnu.org/licenses/gpl-3.0.en.html">GNU GPLv3</a>.<br><br>
-If you found a bug, or have enhancement ideas, \
-feel free to open an issue on the \
-Github <a href=https://github.com/FreeLanguageTools/ssmtool>repository</a>.
-<br><br>
-This program is yours to keep. There is no EULA you need to agree to. \
-No data is sent to any server other than the configured dictionary APIs. \
+If you found a bug, or have enhancement ideas, 
+feel free to open an issue on the 
+Github <a href=https://github.com/FreeLanguageTools/ssmtool>repository</a>.<br><br>
+
+
+This program is yours to keep. There is no EULA you need to agree to.
+No data is sent to any server other than the configured dictionary APIs.
 Statistics data are stored locally.
 <br><br>
 Credits: <br><a href="https://en.wiktionary.org/wiki/Wiktionary:Main_Page">Wiktionary API</a><br>
-<a href="https://dictionaryapi.dev/">Google Dictionary API</a><br>
-If you find this tool useful, you probably should donate to these projects.
+If you find this tool useful, you can donate to these projects.
             '''
         )
         self.about.setTextFormat(Qt.RichText)
@@ -90,7 +119,7 @@ If you find this tool useful, you probably should donate to these projects.
         self.tabs.addTab(self.tab1, "Dictionary")
         self.tabs.addTab(self.tab2, "Anki")
         self.tabs.addTab(self.tab3, "API")
-        self.tabs.addTab(self.tab4, "Miscellaneous")
+        self.tabs.addTab(self.tab4, "Interface")
         self.tabs.addTab(self.tab5, "About")
 
     def setupWidgets(self):
@@ -98,10 +127,12 @@ If you find this tool useful, you probably should donate to these projects.
         self.gtrans_lang.addItems(code.keys())
         
         self.tab1.layout.addRow(self.lemmatization)
+        self.tab1.layout.addRow(self.forvo)
         self.tab1.layout.addRow(QLabel("Target language"), self.target_language)
         self.tab1.layout.addRow(QLabel("Dictionary source 1"), self.dict_source)
         self.tab1.layout.addRow(QLabel("Dictionary source 2"), self.dict_source2)
         self.tab1.layout.addRow(QLabel("Google translate: To"), self.gtrans_lang)
+        self.tab1.layout.addRow(self.remove_spaces)
         self.tab1.layout.addRow(self.importdict)
 
 
@@ -113,21 +144,29 @@ If you find this tool useful, you probably should donate to these projects.
         self.tab2.layout.addRow(QLabel('Field name for "Word"'), self.word_field)
         self.tab2.layout.addRow(QLabel('Field name for "Definition"'), self.definition_field)
         self.tab2.layout.addRow(QLabel('Field name for "Definition#2"'), self.definition2_field)
+        self.tab2.layout.addRow(QLabel('Field name for "Pronunciation"'), self.pronunciation_field)
 
         self.tab3.layout.addRow(QLabel('<i>Most users should not need to change these settings.</i>'))
         self.tab3.layout.addRow(QLabel("API host"), self.host)
         self.tab3.layout.addRow(QLabel("API port"), self.port)
 
+        self.tab4.layout.addRow(QLabel("<b>All settings on this tab requires restart to take effect.</b>"))
         self.tab4.layout.addRow(self.allow_editing)
+        self.tab4.layout.addRow(QLabel("Interface layout"), self.orientation)
+        self.tab4.layout.addRow(QLabel("Text scale"), self.text_scale_box)
 
         self.tab5.layout.addWidget(self.about_sa)
         
-
+        self.text_scale.valueChanged.connect(
+            lambda _: self.text_scale_label.setText(format(self.text_scale.value()/100, "1.2f") + "x")
+            )
 
         
     def setupAutosave(self):
         self.allow_editing.clicked.connect(self.syncSettings)
         self.lemmatization.clicked.connect(self.syncSettings)
+        self.remove_spaces.clicked.connect(self.syncSettings)
+        self.forvo.clicked.connect(self.syncSettings)
         self.dict_source.currentTextChanged.connect(self.syncSettings)
         self.dict_source.currentTextChanged.connect(self.loadDict2Options)
         self.dict_source2.currentTextChanged.connect(self.syncSettings)
@@ -147,16 +186,25 @@ If you find this tool useful, you probably should donate to these projects.
         self.definition_field.currentTextChanged.connect(self.checkCorrectness)
         self.definition2_field.currentTextChanged.connect(self.syncSettings)
         self.definition2_field.currentTextChanged.connect(self.checkCorrectness)
+        self.pronunciation_field.currentTextChanged.connect(self.syncSettings)
+        self.pronunciation_field.currentTextChanged.connect(self.checkCorrectness)
         self.anki_api.editingFinished.connect(self.syncSettings)
         self.anki_api.editingFinished.connect(self.loadSettings)
         self.host.textChanged.connect(self.syncSettings)
         self.port.valueChanged.connect(self.syncSettings)
+        self.text_scale.valueChanged.connect(self.syncSettings)
+        self.orientation.currentTextChanged.connect(self.syncSettings)
 
     def loadDictionaries(self):
         self.dict_source.clear()
         dicts = getDictsForLang(code[self.target_language.currentText()])
         self.dict_source.addItems(dicts)
 
+        if code[self.target_language.currentText()] in ["ja", "zh"]:
+            self.remove_spaces.setCheckable(True)
+        else:
+            self.remove_spaces.setCheckable(False)
+
     def loadDict2Options(self):
         curtext = self.dict_source2.currentText()
         self.dict_source2.blockSignals(True)
@@ -173,8 +221,12 @@ If you find this tool useful, you probably should donate to these projects.
 
 
     def loadSettings(self):
+        self.forvo.setChecked(self.settings.value("forvo", False, type=bool))
         self.allow_editing.setChecked(self.settings.value("allow_editing", True, type=bool))
         self.lemmatization.setChecked(self.settings.value("lemmatization", True, type=bool))
+        self.orientation.setCurrentText(self.settings.value("orientation", "Vertical"))
+        self.remove_spaces.setChecked(self.settings.value("remove_spaces", True, type=bool))
+        self.text_scale.setValue(self.settings.value("text_scale", 100, type=int))
         self.target_language.setCurrentText(self.settings.value("target_language"))
         self.loadDictionaries()
         self.dict_source.setCurrentText(self.settings.value("dict_source", "Wiktionary (English)"))
@@ -185,6 +237,9 @@ If you find this tool useful, you probably should donate to these projects.
         self.tags.setText(self.settings.value("tags", "ssmtool"))
         api = self.anki_api.text()
 
+        self.host.setText(self.settings.value("host", "127.0.0.1"))
+        self.port.setValue(self.settings.value("port", 39284, type=int))
+
         try:
             print("API version is: ", getVersion(api))
         except Exception as e:
@@ -202,9 +257,6 @@ If you find this tool useful, you probably should donate to these projects.
         self.note_type.setCurrentText(self.settings.value("note_type"))
         self.loadFields()
 
-        self.host.setText(self.settings.value("host", "127.0.0.1"))
-        self.port.setValue(self.settings.value("port", 39284, type=int))
-
     def loadFields(self):
         print("loading fields")
         api = self.anki_api.text()
@@ -227,26 +279,36 @@ If you find this tool useful, you probably should donate to these projects.
         word = self.word_field.currentText()
         def1 = self.definition_field.currentText()
         def2 = self.definition2_field.currentText()
+        pron = self.pronunciation_field.currentText()
 
         # Block signals temporarily to avoid warning dialogs
         self.sentence_field.blockSignals(True)
         self.word_field.blockSignals(True)
         self.definition_field.blockSignals(True)
         self.definition2_field.blockSignals(True)
+        self.pronunciation_field.blockSignals(True)
 
         self.sentence_field.clear()
         self.sentence_field.addItems(fields)
 
         self.word_field.clear()
         self.word_field.addItems(fields)
+
         self.definition_field.clear()
         self.definition_field.addItems(fields)
+
         self.definition2_field.clear()
         self.definition2_field.addItem("Disabled")
-        self.definition2_field.addItems(fields)       
+        self.definition2_field.addItems(fields)     
+
+        self.pronunciation_field.clear()
+        self.pronunciation_field.addItem("Disabled")
+        self.pronunciation_field.addItems(fields)   
+
         self.sentence_field.setCurrentText(self.settings.value("sentence_field"))
         self.word_field.setCurrentText(self.settings.value("word_field"))
         self.definition_field.setCurrentText(self.settings.value("definition_field"))
+        self.pronunciation_field.setCurrentText(self.settings.value("pronunciation_field"))
 
         if self.sentence_field.findText(sent) != -1:
             self.sentence_field.setCurrentText(sent)
@@ -256,30 +318,42 @@ If you find this tool useful, you probably should donate to these projects.
             self.definition_field.setCurrentText(def1)
         if self.definition2_field.findText(def2) != -1:
             self.definition2_field.setCurrentText(def2)
+        if self.pronunciation_field.findText(def2) != -1:
+            self.pronunciation_field.setCurrentText(def2)
         
         self.sentence_field.blockSignals(False)
         self.word_field.blockSignals(False)
         self.definition_field.blockSignals(False)
         self.definition2_field.blockSignals(False)
+        self.pronunciation_field.blockSignals(False)
 
     def syncSettings(self):
-        print("syncing")
+        self.settings.setValue("forvo", self.forvo.isChecked())
         self.settings.setValue("allow_editing", self.allow_editing.isChecked())
         self.settings.setValue("lemmatization", self.lemmatization.isChecked())
+        self.settings.setValue("orientation", self.orientation.currentText())
         self.settings.setValue("target_language", self.target_language.currentText())
-        self.settings.setValue("deck_name", self.deck_name.currentText())
         self.settings.setValue("dict_source", self.dict_source.currentText())
         self.settings.setValue("dict_source2", self.dict_source2.currentText())
+        self.settings.setValue("remove_spaces", self.remove_spaces.isChecked())
         self.settings.setValue("gtrans_lang", self.gtrans_lang.currentText())
-        self.settings.setValue("tags", self.tags.text())
-        self.settings.setValue("note_type", self.note_type.currentText())
-        self.settings.setValue("sentence_field", self.sentence_field.currentText())
-        self.settings.setValue("word_field", self.word_field.currentText())
-        self.settings.setValue("definition_field", self.definition_field.currentText())
-        self.settings.setValue("definition2_field", self.definition2_field.currentText())
         self.settings.setValue("anki_api", self.anki_api.text())
         self.settings.setValue("host", self.host.text())
         self.settings.setValue("port", self.port.value())
+        self.settings.setValue("text_scale", self.text_scale.value())
+        try:
+            api = self.anki_api.text()
+            getVersion(api)
+            self.settings.setValue("deck_name", self.deck_name.currentText())
+            self.settings.setValue("note_type", self.note_type.currentText())
+            self.settings.setValue("tags", self.tags.text())
+            self.settings.setValue("sentence_field", self.sentence_field.currentText())
+            self.settings.setValue("word_field", self.word_field.currentText())
+            self.settings.setValue("definition_field", self.definition_field.currentText())
+            self.settings.setValue("definition2_field", self.definition2_field.currentText())
+            self.settings.setValue("pronunciation_field", self.pronunciation_field.currentText())
+        except Exception as e:
+            pass
         self.settings.sync()
     
     def errorNoConnection(self, error):
