@@ -7,8 +7,11 @@ import functools
 import platform
 import json
 from collections import deque
-
+import re
+QCoreApplication.setApplicationName("ssmtool")
+QCoreApplication.setOrganizationName("FreeLanguageTools")
 from .config import *
+from .forvo import *
 from .tools import *
 from .db import *
 from .dictionary import *
@@ -56,8 +59,13 @@ class DictionaryWindow(QMainWindow):
         self.rec = Record()
         self.setCentralWidget(self.widget)
         self.previousWord = ""
+        self.audio_path = ""
+        self.scaleFont()
         self.initWidgets()
-        self.setupWidgets()
+        if self.settings.value("orientation", "Vertical") == "Vertical":
+            self.setupWidgetsV()
+        else:
+            self.setupWidgetsH()
         self.startServer()
         self.initTimer()
         self.updateAnkiButtonState()
@@ -67,6 +75,11 @@ class DictionaryWindow(QMainWindow):
         GlobalObject().addEventListener("double clicked", self.lookupClicked)
         QApplication.clipboard().dataChanged.connect(self.clipboardChanged)
 
+    def scaleFont(self):
+        font = QApplication.font()
+        font.setPointSize(font.pointSize() * self.settings.value("text_scale", type=int)/100)
+        self.setFont(font)
+
     def focusInEvent(self, event):
         self.clipboardChanged(evenWhenFocused=True)
         super().focusInEvent(event)
@@ -104,7 +117,7 @@ class DictionaryWindow(QMainWindow):
         self.sentence.setReadOnly(not (self.settings.value("allow_editing", True, type=bool)))
         self.definition.setReadOnly(not (self.settings.value("allow_editing", True, type=bool)))
 
-    def setupWidgets(self):
+    def setupWidgetsV(self):
         self.layout = QGridLayout(self.widget)
         self.layout.addWidget(self.namelabel, 0, 0, 1, 3)
 
@@ -154,6 +167,62 @@ class DictionaryWindow(QMainWindow):
 
         self.bar.addPermanentWidget(self.stats_label)
 
+    def setupWidgetsH(self):
+        self.layout = QGridLayout(self.widget)
+        self.sentence.setMaximumHeight(1300)
+        self.layout.addWidget(self.namelabel, 0, 0, 1, 3)
+        self.layout.setRowStretch(2, 1)
+        self.layout.setRowStretch(3, 1)
+        self.layout.setRowStretch(4, 1)
+        self.layout.setRowStretch(5, 1)
+        self.layout.setColumnStretch(0, 5)
+        self.layout.setColumnStretch(1, 5)
+        self.layout.setColumnStretch(2, 4)
+        self.layout.setColumnStretch(3, 5)
+        self.layout.setColumnStretch(4, 5)
+
+        self.layout.addWidget(self.label_sentence, 1, 0)
+        self.layout.addWidget(self.undo_button, 6, 0)
+        self.layout.addWidget(self.read_button, 6, 1)
+
+        self.layout.addWidget(self.sentence, 2, 0, 4, 2)
+        self.layout.addWidget(QLabel("Word"), 1, 2)
+
+        if self.settings.value("lemmatization", True, type=bool):
+            self.layout.addWidget(self.lookup_button, 3, 2)
+            self.layout.addWidget(self.lookup_exact_button, 4, 2)
+        else:
+            self.layout.addWidget(self.lookup_button, 1, 4, 2, 1)
+        
+        self.layout.addWidget(QLabel("Definition"), 1, 3)
+        self.layout.addWidget(self.word, 2, 2, 1, 1)
+        if self.settings.value("dict_source2", "Disabled") != "Disabled":
+            print(self.settings.value("dict_source2", "Disabled") != "Disabled")
+            self.layout.addWidget(self.definition, 2, 3, 2, 2)
+            self.layout.addWidget(self.definition2, 4, 3, 2, 2)
+        else:
+            self.layout.addWidget(self.definition, 2, 3, 4, 2)
+
+        
+        self.layout.addWidget(QLabel("Additional tags"), 5, 2, 1, 1)
+
+        self.layout.addWidget(self.tags, 6, 2)
+
+        self.layout.addWidget(self.toanki_button, 6, 3, 1, 1)
+        self.layout.addWidget(self.config_button, 6, 4, 1, 1)
+
+        self.lookup_button.clicked.connect(lambda _: self.lookupClicked(True))
+        self.lookup_exact_button.clicked.connect(lambda _: self.lookupClicked(False))
+
+        self.config_button.clicked.connect(self.configure)
+        self.toanki_button.clicked.connect(self.createNote)
+        self.read_button.clicked.connect(lambda _: self.clipboardChanged(True))
+
+        self.sentence.textChanged.connect(self.updateAnkiButtonState)
+        self.undo_button.clicked.connect(self.undo)
+
+        self.bar.addPermanentWidget(self.stats_label)
+   
     def updateAnkiButtonState(self, forceDisable=False):
         if self.sentence.toPlainText() == "" or forceDisable:
             self.toanki_button.setEnabled(False)
@@ -172,9 +241,9 @@ class DictionaryWindow(QMainWindow):
 
     def getCurrentWord(self):
         cursor = self.sentence.textCursor()
-        selected = cursor.selectedText().lower()
+        selected = cursor.selectedText()
         cursor2 = self.definition.textCursor()
-        selected2 = cursor2.selectedText().lower()
+        selected2 = cursor2.selectedText()
         target = str.strip(selected or selected2
                                     or self.previousWord
                                     or self.word.text()
@@ -185,7 +254,6 @@ class DictionaryWindow(QMainWindow):
 
     def lookupClicked(self, use_lemmatize=True):
         target = self.getCurrentWord()
-        print(use_lemmatize)
         self.updateAnkiButtonState()
         if target == "":
             return
@@ -226,22 +294,25 @@ class DictionaryWindow(QMainWindow):
         mistakes, unless it is used from the button.
         """
         text = QApplication.clipboard().text()
+        remove_spaces = self.settings.value("remove_spaces")
+        lang = code[self.settings.value("target_language")]
         if self.isActiveWindow() and not evenWhenFocused:
             return
         if is_json(text):
             copyobj = json.loads(text)
             target = copyobj['word']
-            self.setSentence(copyobj['sentence'])
+            sentence = preprocess_clipboard(copyobj['sentence'], lang)
+            self.setSentence(sentence)
             self.setWord(target)
             result = self.lookup(target)
             self.setState(result)
-        elif is_oneword(text):
-            self.setSentence(text)
-            self.setWord(text)
+        elif is_oneword(preprocess_clipboard(text, lang)):
+            self.setSentence(word:=preprocess_clipboard(text, lang))
+            self.setWord(word)
             result = self.lookup(text)
             self.setState(result)
         else:
-            self.setSentence(text)
+            self.setSentence(preprocess_clipboard(text, lang))
 
     def lookup(self, word, use_lemmatize=True):
         """
@@ -255,7 +326,11 @@ class DictionaryWindow(QMainWindow):
         language = code[TL] #This is in two letter code
         gtrans_lang = self.settings.value("gtrans_lang", "English")
         dictname = self.settings.value("dict_source", "Wiktionary (English)")
+        word = re.sub('[«»…()\[\]]*', "", word)
+        self.audio_path = None
         self.status(f"L: '{word}' in '{language}', lemma: {short_sign}, from {dictionaries.get(dictname, dictname)}")
+        if self.settings.value("forvo", False):
+            self.audio_path = play_forvo(word, language)
         try:
             item = lookupin(word, language, lemmatize, dictname, gtrans_lang)
             self.rec.recordLookup(word, item['definition'], TL, lemmatize, dictionaries.get(dictname, dictname), True)
@@ -283,6 +358,8 @@ class DictionaryWindow(QMainWindow):
 
     def createNote(self):
         sentence = self.sentence.toPlainText().replace("\n", "<br>")
+        if self.settings.value("remove_spaces", type=bool) == True:
+            sentence = re.sub("\s", "", sentence)
         tags = (self.settings.value("tags", "ssmtool").strip() + " " + self.tags.text().strip()).split(" ")
         word = self.word.text()
         content = {
@@ -306,6 +383,15 @@ class DictionaryWindow(QMainWindow):
             except Exception as e:
                 return
 
+        if self.settings.value("pronunciation_field", "Disabled") != 'Disabled' and self.audio_path:
+            content['audio'] = {
+                "path": self.audio_path,
+                "filename": path.basename(self.audio_path),
+                "fields": [
+                    self.settings.value("pronunciation_field")
+                ]
+            }
+
         self.status("Adding note")
         api = self.settings.value("anki_api")
         try:
@@ -385,11 +471,12 @@ class MyTextEdit(QTextEdit):
     def mouseDoubleClickEvent(self, e):
         super().mouseDoubleClickEvent(e)
         GlobalObject().dispatchEvent("double clicked")
-        print("Event sent")
         self.textCursor().clearSelection()
 
 def main():
     app = QApplication(sys.argv)
+    app.setApplicationName("ssmtool")
+    app.setOrganizationName("FreeLanguageTools")
     w = DictionaryWindow()
 
     w.show()
